function ratfun = diff(obj)
%DIFF   Differentiate an RKFUN.

  % Get Ritz values and poles.
  ee = eig(obj.H(1:end-1,1:end),obj.K(1:end-1,1:end));
  xi = poles(obj);

  % Build 3rd order jordan matrix A and vector b.
  A = sparse([]);
  b = [];
  for j = 1:length(ee)
    A = blkdiag(A, sparse(diag([1 1 1 1]*ee(j)) + ...
                          diag([1 1 1], 1)));
    b = [b; 0; 0; 0; 1];
  end

  % Vector of 3rd, 2nd and 1st order derivatives.
  v  = feval(obj,A,b);
  d3 = 6*v(1:4:end);
  d2 = 2*v(2:4:end);
  d1 =   v(3:4:end);

  % Build 2nd order jordan matrix A, F, and vector b.
  A = sparse([]);
  F = sparse([]);
  b = [];
  for j = 1:length(ee)
    F = blkdiag(F, ...
                sparse([d1(j), d2(j), d3(j)/2; ...
                        0,     d1(j), d2(j);   ...
                        0,     0,     d1(j)]));
    A = blkdiag(A, ...
                sparse(diag([ee(j) ee(j) ee(j)]) + ...
                       diag([1 1], 1)));
    b = [b; 0; 0; 1];
  end

  t = type(obj);
  param.k     = t(1)-t(2)-1;
  param.maxit = 0;
  param.tol   = 0;
  param.real  = isreal(obj);
  param.reduction = 0;
  
  [~, ratfun] = rkfit(F, A, b, [xi; xi], param);

end
