function [x, success] = util_cplxpair(x)
% UTIL_CPLXPAIR    Sorts a vector keeping together
%                  exact complex-conjugate pairs.  
%
% [x, success] = util_cplxpair(x) is used to sort the array x in
% complex conjugate pairs if possible. Matlab's function cplxpair
% does the same but it will break with an error if no pairing
% exists. If the pairing is not possible the array x remains
% unaltered, and the flag success is set to false, otherwise it set
% to true. If the pairing exists, x will be ordered by cplxpair.  
%
% See also cplxpair.
  
  try
    x = cplxpair(x);
    success = true;
  catch
    success = false;
  end
  
end
